HFOSS@RIT
Author: RemyD
Description: RIT HFOSS course website

# Add Yourself To The Course Website

Check out the source repository for this course; it's hosted at https://github.com/decause/hflossk.

Inside the repository, we'll keep an index of all the students in the course and metadata about them (you!).

### Tasks:

- Load up the git cheatsheet at Zack Rusin's blog and keep it nearby.
- Work through this git tutorial if you don't have any experience with git.
- Fork the repository (link to github help on this).
- Clone a local copy.
- Add a file in the `/scripts/people` folder titled `$YOUR_IRC_NICK.yaml`. Perhaps obviously, it is a YAML file. You can use the `rjbpop.yaml` file as an example.
  BE WARNED: Your .yaml file must match the format *exactly* (meaning it is case and whitespace sensitive.)
  CRUFTY: There is a `people.yaml` file in that directory. It is a legacy hangover from older code. Do not bother editing it. It will actually make merges more difficult.
- Once you've confirmed your .yaml file matches exactly, commit and push your changes to github, and issue a pull request.
- Once the patch is accepted upstream and pushed to production, this should add your blog feed to the Participants page.)